package com.gic.evaluate.service.outer.impl;

import com.gic.api.base.commons.ServiceResponse;
import com.gic.commons.util.EntityUtil;
import com.gic.enterprise.response.EnterpriseServiceResponse;
import com.gic.evaluate.constant.QuickReplyTypeEnum;
import com.gic.evaluate.dto.BadEvaluateConfigDTO;
import com.gic.evaluate.dto.EvaluateOrderConfigDTO;
import com.gic.evaluate.entity.TabBadEvaluateConfig;
import com.gic.evaluate.entity.TabEvaluateOrderConfig;
import com.gic.evaluate.entity.TabEvaluateQuick;
import com.gic.evaluate.service.BadEvaluateConfigService;
import com.gic.evaluate.service.EvaluateConfigApiService;
import com.gic.evaluate.service.EvaluateOrderConfigService;
import com.gic.evaluate.service.EvaluateQuickService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.Collections;
import java.util.List;
import java.util.Optional;
import java.util.stream.Collectors;

/**
 *
 * @Description:
 * @author zhiwj
 * @date 2019-12-25 17:41
 */
@Service("evaluateConfigApiService")
public class EvaluateConfigApiServiceImpl implements EvaluateConfigApiService {

    @Autowired
    private EvaluateOrderConfigService evaluateOrderConfigService;
    @Autowired
    private BadEvaluateConfigService badEvaluateConfigService;
    @Autowired
    private EvaluateQuickService evaluateQuickService;


    @Override
    public ServiceResponse<Void> init(Integer enterpriseId) {
        if (evaluateOrderConfigService.getEvaluateOrderConfig(enterpriseId) == null) {
            evaluateOrderConfigService.init(enterpriseId);
        }
        if (badEvaluateConfigService.getBadEvaluateConfig(enterpriseId) == null) {
            badEvaluateConfigService.init(enterpriseId);
        }
        return EnterpriseServiceResponse.success();
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ServiceResponse<Void> updateEvaluateOrderConfig(EvaluateOrderConfigDTO evaluateOrderConfigDTO) {
        evaluateOrderConfigService.updateOrderConfig(evaluateOrderConfigDTO);
        List<String> badEvaluateQuick = evaluateOrderConfigDTO.getBadEvaluateQuick();
        List<String> goodEvaluateQuick = evaluateOrderConfigDTO.getGoodEvaluateQuick();
        List<String> replyQuick = evaluateOrderConfigDTO.getReplyQuick();
        evaluateQuickService.saveEvaluateQuick(evaluateOrderConfigDTO.getEnterpriseId(), badEvaluateQuick, QuickReplyTypeEnum.BAD.getCode());
        evaluateQuickService.saveEvaluateQuick(evaluateOrderConfigDTO.getEnterpriseId(), goodEvaluateQuick, QuickReplyTypeEnum.GOOD.getCode());
        evaluateQuickService.saveEvaluateQuick(evaluateOrderConfigDTO.getEnterpriseId(), replyQuick, QuickReplyTypeEnum.MANAGE.getCode());
        return EnterpriseServiceResponse.success();
    }

    @Override
    public ServiceResponse<Void> updateBadEvaluateConfig(BadEvaluateConfigDTO badEvaluateConfigDTO) {
        badEvaluateConfigService.updateBadEvaluateConfig(badEvaluateConfigDTO);
        return EnterpriseServiceResponse.success();
    }

    @Override
    public ServiceResponse<EvaluateOrderConfigDTO> getEvaluateOrderConfig(Integer enterpriseId) {
        TabEvaluateOrderConfig evaluateOrderConfig = evaluateOrderConfigService.getEvaluateOrderConfig(enterpriseId);
        EvaluateOrderConfigDTO evaluateOrderConfigDTO = EntityUtil.changeEntityByJSON(EvaluateOrderConfigDTO.class, evaluateOrderConfig);
        List<TabEvaluateQuick> badEvaluateQuickList = evaluateQuickService.listEvaluateQuick(enterpriseId, QuickReplyTypeEnum.BAD.getCode());
        List<TabEvaluateQuick> goodEvaluateQuickList = evaluateQuickService.listEvaluateQuick(enterpriseId, QuickReplyTypeEnum.GOOD.getCode());
        List<TabEvaluateQuick> manageEvaluateQuickList = evaluateQuickService.listEvaluateQuick(enterpriseId, QuickReplyTypeEnum.MANAGE.getCode());

        List<String> badEvaluateQuick = Optional.ofNullable(badEvaluateQuickList).orElse(Collections.emptyList()).stream().map(TabEvaluateQuick::getTagName).collect(Collectors.toList());
        List<String> goodEvaluateQuick = Optional.ofNullable(goodEvaluateQuickList).orElse(Collections.emptyList()).stream().map(TabEvaluateQuick::getTagName).collect(Collectors.toList());
        List<String> manageEvaluateQuick = Optional.ofNullable(manageEvaluateQuickList).orElse(Collections.emptyList()).stream().map(TabEvaluateQuick::getTagName).collect(Collectors.toList());

        evaluateOrderConfigDTO.setBadEvaluateQuick(badEvaluateQuick);
        evaluateOrderConfigDTO.setGoodEvaluateQuick(goodEvaluateQuick);
        evaluateOrderConfigDTO.setReplyQuick(manageEvaluateQuick);

        return EnterpriseServiceResponse.success(evaluateOrderConfigDTO);
    }

    @Override
    public ServiceResponse<BadEvaluateConfigDTO> getBadEvaluateConfig(Integer enterpriseId) {
        TabBadEvaluateConfig badEvaluateConfig = badEvaluateConfigService.getBadEvaluateConfig(enterpriseId);
        return EnterpriseServiceResponse.success(EntityUtil.changeEntityByJSON(BadEvaluateConfigDTO.class, badEvaluateConfig));
    }
}
